*******************
Visualization tools
*******************

.. default-role:: obj

.. toctree::
   :caption: Examples and tutorials
   :maxdepth: 1

   gephi-tutorial
   examples/plot_spikes
   examples/cuda_convnet/imagenet_visualization

GraphViz diagrams
=================

.. autosummary::

   nengo_extras.graphviz.net_diagram
   nengo_extras.graphviz.obj_conn_diagram

.. autofunction:: nengo_extras.graphviz.net_diagram

.. autofunction:: nengo_extras.graphviz.obj_conn_diagram

Image manipulation
==================

.. autosummary::

   nengo_extras.gui.preprocess_display
   nengo_extras.gui.image_function
   nengo_extras.gui.image_string_function
   nengo_extras.gui.image_html_function
   nengo_extras.gui.image_display_function

.. autofunction:: nengo_extras.gui.preprocess_display

.. autofunction:: nengo_extras.gui.image_function

.. autofunction:: nengo_extras.gui.image_string_function

.. autofunction:: nengo_extras.gui.image_html_function

.. autofunction:: nengo_extras.gui.image_display_function

Matplotlib plots
================

.. autosummary::

   nengo_extras.matplotlib.imshow
   nengo_extras.matplotlib.tile
   nengo_extras.matplotlib.compare
   nengo_extras.plot_spikes.plot_spikes
   nengo_extras.plot_spikes.preprocess_spikes
   nengo_extras.plot_spikes.cluster
   nengo_extras.plot_spikes.merge
   nengo_extras.plot_spikes.sample_by_variance
   nengo_extras.plot_spikes.sample_by_activity

.. autofunction:: nengo_extras.matplotlib.imshow

.. autofunction:: nengo_extras.matplotlib.tile

.. autofunction:: nengo_extras.matplotlib.compare

.. autofunction:: nengo_extras.plot_spikes.plot_spikes

.. autofunction:: nengo_extras.plot_spikes.preprocess_spikes

.. autofunction:: nengo_extras.plot_spikes.cluster

.. autofunction:: nengo_extras.plot_spikes.merge

.. autofunction:: nengo_extras.plot_spikes.sample_by_variance

.. autofunction:: nengo_extras.plot_spikes.sample_by_activity

TkInter GUIs
============

.. autosummary::

   nengo_extras.deepview.ImageSelector
   nengo_extras.deepview.ScrollCanvasFrame
   nengo_extras.deepview.ScrollWindow
   nengo_extras.deepview.VerticalImageFrame
   nengo_extras.deepview.Viewer

.. autoclass:: nengo_extras.deepview.ImageSelector

.. autoclass:: nengo_extras.deepview.ScrollCanvasFrame

.. autoclass:: nengo_extras.deepview.ScrollWindow

.. autoclass:: nengo_extras.deepview.VerticalImageFrame

.. autoclass:: nengo_extras.deepview.Viewer

Gephi visualization
===================

.. autosummary::

   nengo_extras.gexf.DispatchTable
   nengo_extras.gexf.HierarchicalLabeler
   nengo_extras.gexf.GexfConverter
   nengo_extras.gexf.CollapsingGexfConverter
   nengo_extras.gexf.Attr

.. autoclass:: nengo_extras.gexf.DispatchTable

.. autoclass:: nengo_extras.gexf.HierarchicalLabeler

.. autoclass:: nengo_extras.gexf.GexfConverter

.. autoclass:: nengo_extras.gexf.CollapsingGexfConverter

.. autoclass:: nengo_extras.gexf.Attr
